@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -50,6 +55,7 @@ using namespace std;
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_BEGIN
+#ifdef __cplusplus
 
 FunctionDefinition::FunctionDefinition (unsigned int level, unsigned int version) :
    SBase ( level, version )
@@ -360,7 +366,42 @@ FunctionDefinition::unsetName ()
 const ASTNode*
 FunctionDefinition::getArgument (unsigned int n) const
 {
-  return (n < getNumArguments()) ? mMath->getChild(n) : NULL;
+  if (mMath == NULL) return NULL;
+  
+  /* if the math is not a lambda this function can cause issues
+   * elsewhere, technically if the math is not a lambda
+   * function the body is NULL
+   */
+  ASTNode * lambda = NULL;
+
+  if (mMath->isLambda() == true)
+  {
+    lambda = mMath;
+  }
+  else
+  {
+    if ((getLevel() == 2 && getVersion() > 2) || getLevel() > 2)
+    {
+      if (mMath->isSemantics() == true && mMath->getNumChildren() == 1
+        && mMath->getChild(0)->isLambda() == true)
+      {
+        lambda = mMath->getChild(0);
+      }
+    }
+  }
+
+  if (lambda == NULL)
+  {
+    return NULL;
+  }
+  else if (n < getNumArguments())
+  {
+    return lambda->getChild(n);
+  }
+  else
+  {
+    return NULL;
+  }
 }
 
 
@@ -398,21 +439,44 @@ const ASTNode*
 FunctionDefinition::getBody () const
 {
   if (mMath == NULL) return NULL;
+  
   /* if the math is not a lambda this function can cause issues
    * elsewhere, technically if the math is not a lambda
    * function the body is NULL
    */
-  if (!(mMath->isLambda())) return NULL;
+  ASTNode * lambda = NULL;
 
-  unsigned int nc = mMath->getNumChildren();
+  if (mMath->isLambda() == true)
+  {
+    lambda = mMath;
+  }
+  else
+  {
+    if ((getLevel() == 2 && getVersion() > 2) || getLevel() > 2)
+    {
+      if (mMath->isSemantics() == true && mMath->getNumChildren() == 1
+        && mMath->getChild(0)->isLambda() == true)
+      {
+        lambda = mMath->getChild(0);
+      }
+    }
+  }
+
+  if (lambda == NULL)
+  {
+    return NULL;
+  }
+
+
+  unsigned int nc = lambda->getNumChildren();
   /* here we do actually need to look at whether something is a bvar
    * and not just assume that the last child is a function body 
    * it should be BUT it might not be
    */
 
-  if (nc > 0 && !(mMath->getChild(nc-1)->isBvar()))
+  if (nc > 0 && lambda->getNumBvars() < nc)
   {
-    return mMath->getChild(nc-1);
+    return lambda->getChild(nc-1);
   }
   else
   {
@@ -428,23 +492,45 @@ FunctionDefinition::getBody () const
 ASTNode*
 FunctionDefinition::getBody ()
 {
-   if (mMath == NULL) return NULL;
-
+  if (mMath == NULL) return NULL;
+  
   /* if the math is not a lambda this function can cause issues
    * elsewhere, technically if the math is not a lambda
    * function the body is NULL
    */
-  if (!(mMath->isLambda())) return NULL;
+  ASTNode * lambda = NULL;
 
-  unsigned int nc = mMath->getNumChildren();
+  if (mMath->isLambda() == true)
+  {
+    lambda = mMath;
+  }
+  else
+  {
+    if ((getLevel() == 2 && getVersion() > 2) || getLevel() > 2)
+    {
+      if (mMath->isSemantics() == true && mMath->getNumChildren() == 1
+        && mMath->getChild(0)->isLambda() == true)
+      {
+        lambda = mMath->getChild(0);
+      }
+    }
+  }
+
+  if (lambda == NULL)
+  {
+    return NULL;
+  }
+
+
+  unsigned int nc = lambda->getNumChildren();
   /* here we do actually need to look at whether something is a bvar
    * and not just assume that the last child is a function body 
    * it should be BUT it might not be
    */
 
-  if (nc > 0 && !(mMath->getChild(nc-1)->isBvar()))
+  if (nc > 0 && lambda->getNumBvars() < nc)
   {
-    return mMath->getChild(nc-1);
+    return lambda->getChild(nc-1);
   }
   else
   {
@@ -470,25 +556,40 @@ FunctionDefinition::isSetBody () const
 unsigned int
 FunctionDefinition::getNumArguments () const
 {
+  if (isSetMath() == false)
+  {
+    return 0;
+  }
+
   /* if the math is not a lambda this function can cause issues
    * elsewhere, technically if the math is not a lambda
    * function there are no arguments
    */
-  if ( !isSetMath()
-    || !(mMath->isLambda())
-    || mMath->getNumChildren() == 0) 
+  ASTNode * lambda = NULL;
+
+  if (mMath->isLambda() == true)
+  {
+    lambda = mMath;
+  }
+  else
+  {
+    if ((getLevel() == 2 && getVersion() > 2) || getLevel() > 2)
+    {
+      if (mMath->isSemantics() == true && mMath->getNumChildren() == 1
+        && mMath->getChild(0)->isLambda() == true)
+      {
+        lambda = mMath->getChild(0);
+      }
+    }
+  }
+
+  if ( lambda == NULL)
+  {
     return 0;
+  }
   else 
   {
-    /* here we do actually need to look at whether something is a bvar
-     * and not just assume that the last child is a function body 
-     */
-
-    unsigned int num = mMath->getNumChildren();
-    if (mMath->getChild(num-1)->isBvar())
-      return num;
-    else
-      return num - 1;
+    return lambda->getNumBvars();
   }
 }
 
@@ -1008,28 +1109,9 @@ ListOfFunctionDefinitions::createObject (XMLInputStream& stream)
 /** @endcond */
 
 
-/** @cond doxygenCOnly */
+#endif /* __cplusplus */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a new FunctionDefinition_t structure using the given SBML @p level
- * and @p version values.
- *
- * @param level an unsigned int, the SBML Level to assign to this
- * FunctionDefinition
- *
- * @param version an unsigned int, the SBML Version to assign to this
- * FunctionDefinition
- *
- * @return a pointer to the newly created FunctionDefinition_t structure.
- *
- * @note Once a FunctionDefinition has been added to an SBMLDocument, the @p
- * level and @p version for the document @em override those used to create
- * the FunctionDefinition.  Despite this, the ability to supply the values at
- * creation time is an important aid to creating valid SBML.  Knowledge of
- * the intended SBML Level and Version  determine whether it is valid to
- * assign a particular value to an attribute, or whether it is valid to add
- * an object to an existing SBMLDocument.
- */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 FunctionDefinition_create (unsigned int level, unsigned int version)
@@ -1046,23 +1128,6 @@ FunctionDefinition_create (unsigned int level, unsigned int version)
 }
 
 
-/**
- * Creates a new FunctionDefinition_t structure using the given
- * SBMLNamespaces_t structure.
- *
- * @param sbmlns SBMLNamespaces, a pointer to an SBMLNamespaces structure
- * to assign to this FunctionDefinition
- *
- * @return a pointer to the newly created FunctionDefinition_t structure.
- *
- * @note Once a FunctionDefinition has been added to an SBMLDocument, the
- * @p sbmlns namespaces for the document @em override those used to create
- * the FunctionDefinition.  Despite this, the ability to supply the values at 
- * creation time is an important aid to creating valid SBML.  Knowledge of the 
- * intended SBML Level and Version determine whether it is valid to assign a 
- * particular value to an attribute, or whether it is valid to add an object to 
- * an existing SBMLDocument.
- */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 FunctionDefinition_createWithNS (SBMLNamespaces_t* sbmlns)
@@ -1079,11 +1144,6 @@ FunctionDefinition_createWithNS (SBMLNamespaces_t* sbmlns)
 }
 
 
-/**
- * Frees the given FunctionDefinition.
- *
- * @param fd the FunctionDefinition_t structure
- */
 LIBSBML_EXTERN
 void
 FunctionDefinition_free (FunctionDefinition_t *fd)
@@ -1093,13 +1153,6 @@ FunctionDefinition_free (FunctionDefinition_t *fd)
 }
 
 
-/**
- * Creates a deep copy of the given FunctionDefinition_t structure
- * 
- * @param fd the FunctionDefinition_t structure to be copied
- * 
- * @return a (deep) copy of the given FunctionDefinition_t structure.
- */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 FunctionDefinition_clone (const FunctionDefinition_t* fd)
@@ -1108,15 +1161,6 @@ FunctionDefinition_clone (const FunctionDefinition_t* fd)
 }
 
 
-/**
- * Returns a list of XMLNamespaces_t associated with this FunctionDefinition_t
- * structure.
- *
- * @param fd the FunctionDefinition_t structure
- * 
- * @return pointer to the XMLNamespaces_t structure associated with 
- * this SBML object
- */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
 FunctionDefinition_getNamespaces(FunctionDefinition_t *fd)
@@ -1125,14 +1169,6 @@ FunctionDefinition_getNamespaces(FunctionDefinition_t *fd)
 }
 
 
-/**
- * Get the identifier of the given FunctionDefinition_t structure.
- *
- * @param fd the FunctionDefinition_t structure
- * 
- * @return the value of the "id" attribute of this FunctionDefinition_t
- * structure.
- */
 LIBSBML_EXTERN
 const char *
 FunctionDefinition_getId (const FunctionDefinition_t *fd)
@@ -1141,13 +1177,6 @@ FunctionDefinition_getId (const FunctionDefinition_t *fd)
 }
 
 
-/**
- * Get the name of the given FunctionDefinition_t structure.
- *
- * @param fd the FunctionDefinition_t structure
- *
- * @return the name of this FunctionDefinition_t structure.
- */
 LIBSBML_EXTERN
 const char *
 FunctionDefinition_getName (const FunctionDefinition_t *fd)
@@ -1156,14 +1185,6 @@ FunctionDefinition_getName (const FunctionDefinition_t *fd)
 }
 
 
-/**
- * Get the mathematical formula implemented by the given function.
- *
- * @param fd the FunctionDefinition_t structure
- * 
- * @return an ASTNode_t tree representing the mathematical formula of this
- * FunctionDefinition_t structure.
- */
 LIBSBML_EXTERN
 const ASTNode_t *
 FunctionDefinition_getMath (const FunctionDefinition_t *fd)
@@ -1172,15 +1193,6 @@ FunctionDefinition_getMath (const FunctionDefinition_t *fd)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * Compartment_t structure's "id" attribute is set.
- *
- * @param fd the FunctionDefinition_t structure
- *
- * @return nonzero if the "id" attribute of the FunctionDefinition_t
- * structure is set, zero (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 FunctionDefinition_isSetId (const FunctionDefinition_t *fd)
@@ -1189,15 +1201,6 @@ FunctionDefinition_isSetId (const FunctionDefinition_t *fd)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * Compartment_t structure's "name" attribute is set.
- *
- * @param fd the FunctionDefinition_t structure
- *
- * @return nonzero if the "name" attribute of the FunctionDefinition_t
- * structure is set, zero (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 FunctionDefinition_isSetName (const FunctionDefinition_t *fd)
@@ -1206,15 +1209,6 @@ FunctionDefinition_isSetName (const FunctionDefinition_t *fd)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * Compartment_t structure's "math" subelement is set.
- *
- * @param fd the FunctionDefinition_t structure
- *
- * @return nonzero if the mathematical expression of this
- * FunctionDefinition is set, zero (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 FunctionDefinition_isSetMath (const FunctionDefinition_t *fd)
@@ -1223,23 +1217,6 @@ FunctionDefinition_isSetMath (const FunctionDefinition_t *fd)
 }
 
 
-/**
- * Sets the value of the "id" attribute of a FunctionDefinition_t structure.
- *
- * @param fd the FunctionDefinition_t structure to set.
- *
- * @param sid the identifier to assign to the "id" attribute of @p fd
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with an id of NULL is equivalent to
- * unsetting the "id" attribute.
- */
 LIBSBML_EXTERN
 int
 FunctionDefinition_setId (FunctionDefinition_t *fd, const char *sid)
@@ -1251,23 +1228,6 @@ FunctionDefinition_setId (FunctionDefinition_t *fd, const char *sid)
 }
 
 
-/**
- * Sets the value of the "name" attribute of a FunctionDefinition_t structure.
- *
- * @param fd the FunctionDefinition_t structure to set.
- *
- * @param name the identifier to assign to the "name" attribute of @p fd
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with the name set to NULL is equivalent to
- * unsetting the "name" attribute.
- */
 LIBSBML_EXTERN
 int
 FunctionDefinition_setName (FunctionDefinition_t *fd, const char *name)
@@ -1279,23 +1239,6 @@ FunctionDefinition_setName (FunctionDefinition_t *fd, const char *name)
 }
 
 
-/**
- * Sets the "math" subelement of a given FunctionDefinition_t structure.
- *
- * The ASTNode_t structure given in @p math is copied.
- *
- * @param fd the FunctionDefinition_t structure to set.
- *
- * @param math the ASTNode_t structure to copy and assign to the "math"
- * subelement of the given FunctionDefinition_t structure
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 FunctionDefinition_setMath (FunctionDefinition_t *fd, const ASTNode_t *math)
@@ -1307,18 +1250,6 @@ FunctionDefinition_setMath (FunctionDefinition_t *fd, const ASTNode_t *math)
 }
 
 
-/**
- * Unsets the "name" attribute of the given FunctionDefinition_t structure.
- * 
- * @param fd the FunctionDefinition_t structure
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 FunctionDefinition_unsetName (FunctionDefinition_t *fd)
@@ -1330,16 +1261,6 @@ FunctionDefinition_unsetName (FunctionDefinition_t *fd)
 }
 
 
-/**
- * Get the nth argument (bound variable) to the given FunctionDefinition_t
- * structure.
- * 
- * @param fd the FunctionDefinition_t structure
- *
- * @param n the index of the argument to return
- *
- * @return an ASTNode_t tree structure for the argument.
- */
 LIBSBML_EXTERN
 const ASTNode_t *
 FunctionDefinition_getArgument (const FunctionDefinition_t *fd, unsigned int n)
@@ -1348,16 +1269,6 @@ FunctionDefinition_getArgument (const FunctionDefinition_t *fd, unsigned int n)
 }
 
 
-/**
- * Get the argument named @p name to the given FunctionDefinition_t structure.
- *
- * @param fd the FunctionDefinition_t structure
- *
- * @param name the exact name (case-sensitive) of the sought-after argument
- *
- * @return an ASTNode_t structure representing the argument (bound
- * variable)
- */
 LIBSBML_EXTERN
 const ASTNode_t *
 FunctionDefinition_getArgumentByName ( FunctionDefinition_t *fd,
@@ -1367,15 +1278,6 @@ FunctionDefinition_getArgumentByName ( FunctionDefinition_t *fd,
 }
 
 
-/**
- * Get the mathematical expression that constitutes the body of the given
- * function definition.
- *
- * @param fd the FunctionDefinition_t structure
- * 
- * @return an ASTNode_t tree that is the "math" subelement" of this
- * FunctionDefinition_t structure
- */
 LIBSBML_EXTERN
 const ASTNode_t *
 FunctionDefinition_getBody (const FunctionDefinition_t *fd)
@@ -1384,15 +1286,6 @@ FunctionDefinition_getBody (const FunctionDefinition_t *fd)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether the given
- * FunctionDefinition_t structure's "math" subelement has a body.
- *
- * @param fd the FunctionDefinition_t structure
- *
- * @return nonzero if the body of this
- * FunctionDefinition is set, zero (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 FunctionDefinition_isSetBody (const FunctionDefinition_t *fd)
@@ -1401,16 +1294,6 @@ FunctionDefinition_isSetBody (const FunctionDefinition_t *fd)
 }
 
 
-
-
-/**
- * Get the number of arguments that the given function definition takes.
- *
- * @param fd the FunctionDefinition_t structure
- * 
- * @return the number of arguments (bound variables) that must be passed
- * to this FunctionDefinition_t structure.
- */
 LIBSBML_EXTERN
 unsigned int
 FunctionDefinition_getNumArguments (const FunctionDefinition_t *fd)
@@ -1420,10 +1303,6 @@ FunctionDefinition_getNumArguments (const FunctionDefinition_t *fd)
 
 
 
-/**
- * @return item in this ListOfFunctionDefinition with the given @p id or @c NULL if no such
- * item exists.
- */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 ListOfFunctionDefinitions_getById (ListOf_t *lo, const char *sid)
@@ -1436,11 +1315,6 @@ ListOfFunctionDefinitions_getById (ListOf_t *lo, const char *sid)
 }
 
 
-/**
- * Removes item in this ListOf items with the given @p id or @c NULL if no such
- * item exists.  The caller owns the returned item and is responsible for
- * deleting it.
- */
 LIBSBML_EXTERN
 FunctionDefinition_t *
 ListOfFunctionDefinitions_removeById (ListOf_t *lo, const char *sid)
