@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -46,6 +51,8 @@ using namespace std;
 
 LIBSBML_CPP_NAMESPACE_BEGIN
 
+#ifdef __cplusplus
+
 /** @cond doxygenLibsbmlInternal */
 /*
  * @return true if sboTerm is in the correct format (a zero-padded, seven
@@ -1324,4 +1331,9 @@ SBO::populateSBOTree()
 }
 /** @endcond */
 
+#endif /* __cplusplus */  
+/** @cond doxygenIgnored */
+
+/** @endcond */
+
 LIBSBML_CPP_NAMESPACE_END
