@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -37,6 +42,7 @@
 #include <sbml/util/ElementFilter.h>
 
 LIBSBML_CPP_NAMESPACE_BEGIN
+#ifdef __cplusplus
 
 /** @cond doxygenLibsbmlInternal */
 const std::string SpeciesReferenceGlyph::SPECIES_REFERENCE_ROLE_STRING[]={
@@ -128,7 +134,7 @@ SpeciesReferenceGlyph::SpeciesReferenceGlyph(LayoutPkgNamespaces* layoutns)
  * Creates a new SpeciesReferenceGlyph.  The id is given as the first
  * argument, the id of the associated species reference is given as the
  * second argument.  The third argument is the id of the associated species
- * glpyh and the fourth argument is the role.
+ * glyph and the fourth argument is the role.
  */ 
 SpeciesReferenceGlyph::SpeciesReferenceGlyph
 (
@@ -394,7 +400,7 @@ SpeciesReferenceGlyph::getCurveExplicitlySet() const
 
 
 /*
- * Returns true if the id of the associated species glpyh is not the empty
+ * Returns true if the id of the associated species glyph is not the empty
  * string.
  */ 
 bool
@@ -834,9 +840,9 @@ SpeciesReferenceGlyph::enablePackageInternal(const std::string& pkgURI,
 
 
 
-/**
- * Creates a new SpeciesReferenceGlyph object and returns a pointer to it.
- */
+#endif /* __cplusplus */
+/** @cond doxygenIgnored */
+
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 SpeciesReferenceGlyph_create(void)
@@ -845,9 +851,6 @@ SpeciesReferenceGlyph_create(void)
 }
 
 
-/**
- * Creates a new SpeciesReferenceGlyph from a template.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 SpeciesReferenceGlyph_createFrom (const SpeciesReferenceGlyph_t *temp)
@@ -856,26 +859,19 @@ SpeciesReferenceGlyph_createFrom (const SpeciesReferenceGlyph_t *temp)
 }
 
 
-/**
- * Creates a new SpeciesReferenceGlyph object with the given @p id and returns
- * a pointer to it.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 SpeciesReferenceGlyph_createWith (const char *sid,
-                                  const char *speciesReferenceId,
                                   const char *speciesGlyphId,
+                                  const char *speciesReferenceId,
                                   SpeciesReferenceRole_t role)
 {
   LayoutPkgNamespaces layoutns;
   return new(std::nothrow)
-    SpeciesReferenceGlyph(&layoutns, sid ? sid : "", speciesReferenceId ? speciesReferenceId : "", speciesGlyphId ? speciesGlyphId : "", role);
+    SpeciesReferenceGlyph(&layoutns, sid ? sid : "", speciesGlyphId ? speciesGlyphId : "", speciesReferenceId ? speciesReferenceId : "", role);
 }
 
 
-/**
- * Frees the memory for the SpeciesReferenceGlyph
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_free(SpeciesReferenceGlyph_t *srg)
@@ -884,9 +880,6 @@ SpeciesReferenceGlyph_free(SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Sets the reference species for the species glyph.
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_setSpeciesReferenceId (SpeciesReferenceGlyph_t *srg,
@@ -896,9 +889,6 @@ SpeciesReferenceGlyph_setSpeciesReferenceId (SpeciesReferenceGlyph_t *srg,
 }
 
 
-/**
- * Gets the reference species id for the given species glyph.
- */
 LIBSBML_EXTERN
 const char *
 SpeciesReferenceGlyph_getSpeciesReferenceId (const SpeciesReferenceGlyph_t *srg)
@@ -907,10 +897,6 @@ SpeciesReferenceGlyph_getSpeciesReferenceId (const SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Returns 0 if the reference species reference has not been set for this
- * glyph and 1 otherwise.
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetSpeciesReferenceId
@@ -920,9 +906,6 @@ SpeciesReferenceGlyph_isSetSpeciesReferenceId
 }
 
 
-/**
- * Sets the species glyph reference for the species glyph.
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_setSpeciesGlyphId (SpeciesReferenceGlyph_t *srg,
@@ -932,9 +915,6 @@ SpeciesReferenceGlyph_setSpeciesGlyphId (SpeciesReferenceGlyph_t *srg,
 }
 
 
-/**
- * Gets the reference speciess id for the given species glyph.
- */
 LIBSBML_EXTERN
 const char *
 SpeciesReferenceGlyph_getSpeciesGlyphId (const SpeciesReferenceGlyph_t *srg)
@@ -943,10 +923,6 @@ SpeciesReferenceGlyph_getSpeciesGlyphId (const SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Returns 0 if  the reference species reference has not  been set for this
- * glyph and 1 otherwise.
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetSpeciesGlyphId (const SpeciesReferenceGlyph_t *srg)
@@ -955,9 +931,6 @@ SpeciesReferenceGlyph_isSetSpeciesGlyphId (const SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Sets the curve for the species reference glyph.
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_setCurve(SpeciesReferenceGlyph_t *srg, Curve_t *c)
@@ -966,9 +939,6 @@ SpeciesReferenceGlyph_setCurve(SpeciesReferenceGlyph_t *srg, Curve_t *c)
 }
 
 
-/**
- * Gets the Curve for the given species reference glyph.
- */
 LIBSBML_EXTERN
 Curve_t *
 SpeciesReferenceGlyph_getCurve (SpeciesReferenceGlyph_t *srg)
@@ -977,9 +947,6 @@ SpeciesReferenceGlyph_getCurve (SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Returns true if the Curve has one or more LineSegment.
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetCurve (SpeciesReferenceGlyph_t *srg)
@@ -988,12 +955,6 @@ SpeciesReferenceGlyph_isSetCurve (SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Sets the role of the species reference glyph based on the string.  The
- * string can be one of UNDEFINED, SUBSTRATE, PRODUCT, SIDESUBSTRATE,
- * SIDEPRODUCT, MODIFIER, INHIBITOR or ACTIVATOR.  If it is none of those,
- * the role is set to SPECIES_ROLE_UNDEFINED.
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_setRole (SpeciesReferenceGlyph_t *srg,
@@ -1003,9 +964,6 @@ SpeciesReferenceGlyph_setRole (SpeciesReferenceGlyph_t *srg,
 }
 
 
-/**
- * Returns the role of the species reference.
- */ 
 LIBSBML_EXTERN
 SpeciesReferenceRole_t
 SpeciesReferenceGlyph_getRole (const SpeciesReferenceGlyph_t *srg)
@@ -1013,9 +971,6 @@ SpeciesReferenceGlyph_getRole (const SpeciesReferenceGlyph_t *srg)
   return srg->getRole();
 }
 
-/**
- * Returns a string representation of the role of the species reference.
- */ 
 LIBSBML_EXTERN
 const char*
 SpeciesReferenceGlyph_getRoleString(const SpeciesReferenceGlyph_t* srg){
@@ -1024,9 +979,6 @@ SpeciesReferenceGlyph_getRoleString(const SpeciesReferenceGlyph_t* srg){
 
 
 
-/**
- * Returns true if the role is not SPECIES_ROLE_UNDEFINED.
- */ 
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetRole (const SpeciesReferenceGlyph_t *srg)
@@ -1035,10 +987,6 @@ SpeciesReferenceGlyph_isSetRole (const SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Calls initDefaults on GraphicalObject and sets role to
- * SPECIES_ROLE_UNDEFINED.
- */ 
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_initDefaults (SpeciesReferenceGlyph_t *srg)
@@ -1047,11 +995,6 @@ SpeciesReferenceGlyph_initDefaults (SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Creates a new LineSegment object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 SpeciesReferenceGlyph_createLineSegment (SpeciesReferenceGlyph_t *srg)
@@ -1060,11 +1003,6 @@ SpeciesReferenceGlyph_createLineSegment (SpeciesReferenceGlyph_t *srg)
 }  
 
 
-/**
- * Creates a new CubicBezier object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 SpeciesReferenceGlyph_createCubicBezier (SpeciesReferenceGlyph_t *srg)
@@ -1073,9 +1011,6 @@ SpeciesReferenceGlyph_createCubicBezier (SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * @return a (deep) copy of this SpeciesReferenceGlyph.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 SpeciesReferenceGlyph_clone (const SpeciesReferenceGlyph_t *m)
@@ -1083,9 +1018,6 @@ SpeciesReferenceGlyph_clone (const SpeciesReferenceGlyph_t *m)
   return static_cast<SpeciesReferenceGlyph*>( m->clone() );
 }
 
-/**
- * Returns non-zero if the id is set
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetId (const SpeciesReferenceGlyph_t *srg)
@@ -1093,9 +1025,6 @@ SpeciesReferenceGlyph_isSetId (const SpeciesReferenceGlyph_t *srg)
   return static_cast <int> (srg->isSetId());
 }
 
-/**
- * Returns the id
- */
 LIBSBML_EXTERN
 const char *
 SpeciesReferenceGlyph_getId (const SpeciesReferenceGlyph_t *srg)
@@ -1103,9 +1032,6 @@ SpeciesReferenceGlyph_getId (const SpeciesReferenceGlyph_t *srg)
   return srg->isSetId() ? srg->getId().c_str() : NULL;
 }
 
-/**
- * Sets the id
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_setId (SpeciesReferenceGlyph_t *srg, const char *sid)
@@ -1113,9 +1039,6 @@ SpeciesReferenceGlyph_setId (SpeciesReferenceGlyph_t *srg, const char *sid)
   return (sid == NULL) ? srg->setId("") : srg->setId(sid);
 }
 
-/**
- * Unsets the id
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_unsetId (SpeciesReferenceGlyph_t *srg)
@@ -1123,5 +1046,6 @@ SpeciesReferenceGlyph_unsetId (SpeciesReferenceGlyph_t *srg)
   srg->unsetId();
 }
 
+/** @endcond */
 LIBSBML_CPP_NAMESPACE_END
 
